@@ -1,24 +1,6 @@
 package org.gcube.portal.databook.server;
-
-import java.text.SimpleDateFormat;
-import java.util.Calendar;
-import java.util.Collections;
-import java.util.Comparator;
-import java.util.HashMap;
-import java.util.LinkedHashMap;
-import java.util.LinkedList;
-import java.util.List;
-import java.util.Map;
-import java.util.Map.Entry;
-
-import org.gcube.portal.databook.shared.Feed;
-import org.gcube.portal.databook.shared.ex.ColumnNameNotFoundException;
-import org.gcube.portal.databook.shared.ex.FeedIDNotFoundException;
-import org.gcube.portal.databook.shared.ex.FeedTypeNotFoundException;
-import org.gcube.portal.databook.shared.ex.PrivacyLevelTypeNotFoundException;
 import org.junit.AfterClass;
 import org.junit.BeforeClass;
-import org.junit.Test;
 
 public class DatabookCassandraTest {
 	private static DBCassandraAstyanaxImpl store;
@@ -35,6 +17,49 @@ public class DatabookCassandraTest {
 
 	}
 
+	//	@Test
+	//	public void getRecentCommentedFeedsByUserAndDate() throws Exception{
+	//		String userid = "massimiliano.assante";
+	//		Calendar oneYearAgo = Calendar.getInstance();
+	//		oneYearAgo.set(Calendar.YEAR, oneYearAgo.get(Calendar.YEAR) - 1);
+	//
+	//		long init = System.currentTimeMillis();
+	//		List<Feed> res = store.getRecentCommentedFeedsByUserAndDate(userid, oneYearAgo.getTimeInMillis());
+	//		long end = System.currentTimeMillis();
+	//		System.out.println("Result is " + (end - init));
+	//
+	//
+	//	}
+	//		@Test
+	//		public void getRecentCommentsByUserAndDate() throws Exception{
+	//	
+	//			String userid = "costantino.perciante";
+	//			Calendar oneYearAgo = Calendar.getInstance();
+	//			oneYearAgo.set(Calendar.YEAR, oneYearAgo.get(Calendar.YEAR) - 1);
+	//	
+	//			List<Comment> res = store.getRecentCommentsByUserAndDate(userid, oneYearAgo.getTimeInMillis());
+	//	
+	//			for (Comment comment : res) {
+	//				System.out.println("Result is " + comment);
+	//			}
+	//			
+	//	
+	//	
+	//	
+	//		}
+	//	@Test
+	//	public void getRecentLikedFeedsByUser(){
+	//
+	//		String userid = "costantino.perciante";
+	//		Calendar oneYearAgo = Calendar.getInstance();
+	//		oneYearAgo.set(Calendar.YEAR, oneYearAgo.get(Calendar.YEAR) - 1);
+	//
+	//		List<Feed> result = store.getRecentLikedFeedsByUserAndDate(userid, oneYearAgo.getTimeInMillis());
+	//
+	//		for (Feed feed : result) {
+	//			System.out.println("Result is " + feed);
+	//		}
+	//	}
 	//	@Test
 	//	public void getHashTagsFilteredByTime() throws PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, FeedIDNotFoundException, ColumnNameNotFoundException{
 	//
